# API Python

Documentação detalhada de todos os métodos presentes na biblioteca

----

## Cbers4aAPI

::: cbers4asat.cbers4asat.Cbers4aAPI
    handler: python
    options:
      filters:
        - "!__check_for_exception"
      members_order: source
      show_root_heading: False
      show_root_toc_entry: False
      show_root_full_path: False
      show_source: False
      heading_level: 3

---

## Tools

::: cbers4asat.tools.image
    handler: python
    options:
      members_order: source
      show_root_heading: False
      show_root_toc_entry: False
      show_root_full_path: False
      show_source: False
      heading_level: 3

---

::: cbers4asat.tools.grid
    handler: python
    options:
      members_order: source
      show_root_heading: False
      show_root_toc_entry: False
      show_root_full_path: False
      show_source: False
      heading_level: 3
